==> jc-1.4.0.tar.gz: soot/javaToJimple/LocalUsesChecker.h <==
// public class soot.javaToJimple.LocalUsesChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 95707c34e6d4d91e soot_javaToJimple_LocalUsesChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_LocalUsesChecker_H_
#define _JC_soot_javaToJimple_LocalUsesChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$sub_refs	_jc_soot_javaToJimple_LocalUsesChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs	_jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$refs	_jc_soot_javaToJimple_LocalUsesChecker$refs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$nonrefs	_jc_soot_javaToJimple_LocalUsesChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$object	_jc_soot_javaToJimple_LocalUsesChecker$object;

typedef const struct _jc_soot_javaToJimple_LocalUsesChecker$vmethods	_jc_soot_javaToJimple_LocalUsesChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_LocalUsesChecker$vtable	_jc_soot_javaToJimple_LocalUsesChecker$vtable;
typedef const struct _jc_soot_javaToJimple_LocalUsesChecker$vtype	_jc_soot_javaToJimple_LocalUsesChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_LocalUsesChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *);

// Virtual methods
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_LocalUsesChecker$method$getLocalDecls$a527db0c70470357(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *);
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_LocalUsesChecker$method$getLocals$cf778b43bdbd5ea8(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *);
extern struct _jc_object *_jc_soot_javaToJimple_LocalUsesChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_LocalUsesChecker$method_info$getLocalDecls$a527db0c70470357;
extern _jc_method _jc_soot_javaToJimple_LocalUsesChecker$method_info$getLocals$cf778b43bdbd5ea8;
extern _jc_method _jc_soot_javaToJimple_LocalUsesChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_LocalUsesChecker$vmethods {
	struct _jc_java_util_ArrayList$object	*(*getLocalDecls$a527db0c70470357)(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *);
	struct _jc_java_util_ArrayList$object	*(*getLocals$cf778b43bdbd5ea8)(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_LocalUsesChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_LocalUsesChecker$vmethods	soot_javaToJimple_LocalUsesChecker;
};

// Vtype
struct _jc_soot_javaToJimple_LocalUsesChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_LocalUsesChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalUsesChecker$sub_refs {
	struct _jc_java_util_ArrayList$object	*localDecls;
	struct _jc_java_util_ArrayList$object	*locals;
	struct _jc_java_util_HashMap$object	*map;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_LocalUsesChecker$refs {
    _jc_soot_javaToJimple_LocalUsesChecker$sub_refs	soot_javaToJimple_LocalUsesChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_LocalUsesChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs	soot_javaToJimple_LocalUsesChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_LocalUsesChecker$object {
	_jc_soot_javaToJimple_LocalUsesChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_LocalUsesChecker$vtype	*vtype;
	_jc_soot_javaToJimple_LocalUsesChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_LocalUsesChecker$vtype _jc_soot_javaToJimple_LocalUsesChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_LocalUsesChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_LocalUsesChecker$class_object;

#endif	/* _JC_soot_javaToJimple_LocalUsesChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/LocalUsesChecker.h <==
// public class soot.javaToJimple.LocalUsesChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 95707c34e6d4d91e soot_javaToJimple_LocalUsesChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_LocalUsesChecker_H_
#define _JC_soot_javaToJimple_LocalUsesChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$sub_refs	_jc_soot_javaToJimple_LocalUsesChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs	_jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$refs	_jc_soot_javaToJimple_LocalUsesChecker$refs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$nonrefs	_jc_soot_javaToJimple_LocalUsesChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_LocalUsesChecker$object	_jc_soot_javaToJimple_LocalUsesChecker$object;

typedef const struct _jc_soot_javaToJimple_LocalUsesChecker$vmethods	_jc_soot_javaToJimple_LocalUsesChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_LocalUsesChecker$vtable	_jc_soot_javaToJimple_LocalUsesChecker$vtable;
typedef const struct _jc_soot_javaToJimple_LocalUsesChecker$vtype	_jc_soot_javaToJimple_LocalUsesChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_LocalUsesChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_LocalUsesChecker$method$getLocalDecls$a527db0c70470357(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_LocalUsesChecker$method$getLocals$cf778b43bdbd5ea8(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_LocalUsesChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_LocalUsesChecker$method_info$getLocalDecls$a527db0c70470357;
extern _jc_method _jc_soot_javaToJimple_LocalUsesChecker$method_info$getLocals$cf778b43bdbd5ea8;
extern _jc_method _jc_soot_javaToJimple_LocalUsesChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_LocalUsesChecker$vmethods {
	struct _jc_java_util_ArrayList$object	*(*getLocalDecls$a527db0c70470357)(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_ArrayList$object	*(*getLocals$cf778b43bdbd5ea8)(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_LocalUsesChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_LocalUsesChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_LocalUsesChecker$vmethods	soot_javaToJimple_LocalUsesChecker;
};

// Vtype
struct _jc_soot_javaToJimple_LocalUsesChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_LocalUsesChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalUsesChecker$sub_refs {
	struct _jc_java_util_ArrayList$object	*localDecls;
	struct _jc_java_util_ArrayList$object	*locals;
	struct _jc_java_util_HashMap$object	*map;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_LocalUsesChecker$refs {
    _jc_soot_javaToJimple_LocalUsesChecker$sub_refs	soot_javaToJimple_LocalUsesChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_LocalUsesChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_LocalUsesChecker$sub_nonrefs	soot_javaToJimple_LocalUsesChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_LocalUsesChecker$object {
	_jc_soot_javaToJimple_LocalUsesChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_LocalUsesChecker$vtype	*vtype;
	_jc_soot_javaToJimple_LocalUsesChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_LocalUsesChecker$vtype _jc_soot_javaToJimple_LocalUsesChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_LocalUsesChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_LocalUsesChecker$class_object;

#endif	/* _JC_soot_javaToJimple_LocalUsesChecker_H_ */
